# TG.io
The simplest Python library for Telegram bots based on AsyncIO

[PyPI](https://pypi.org/project/tgio/)

## Update the version [system]
```
python3 setup.py sdist bdist_wheel
python3 -m twine upload dist/*
```